ProgressIndicatorBuilder typedef

ProgressIndicatorBuilder = Widget Function(BuildContext context, String url, DownloadProgress progress)

Builder function to create a progress indicator widget. The function is called every time a chuck of the image is downloaded from the web, but at least once during image loading.

Implementation

typedef ProgressIndicatorBuilder =
    Widget Function(
      BuildContext context,
      String url,
      DownloadProgress progress,
    );