SliverVisibilityDetector class

Inheritance
Available extensions

Constructors

SliverVisibilityDetector({required Key key, required Widget sliver, required VisibilityChangedCallback? onVisibilityChanged})
Constructor.
const

Properties

child → Widget?
The widget below this widget in the tree.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onVisibilityChanged → VisibilityChangedCallback?
The callback to invoke when this widget's visibility changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → SingleChildRenderObjectElement
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
createRenderObject(BuildContext context) → RenderSliverVisibilityDetector
See RenderObjectWidget.createRenderObject.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didUnmountRenderObject(covariant RenderObject renderObject) → void
This method is called when a RenderObject that was previously associated with this widget is removed from the render tree. The provided RenderObject will be of the same type as the one created by this widget's createRenderObject method.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(GestureTapCallback function) → Widget

Available on Widget, provided by the GestureDetectorExtensions extension

onLongPress(GestureTapCallback function) → Widget

Available on Widget, provided by the GestureDetectorExtensions extension

onTap(GestureTapCallback function) → Widget

Available on Widget, provided by the GestureDetectorExtensions extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateRenderObject(BuildContext context, covariant RenderSliverVisibilityDetector renderObject) → void
See RenderObjectWidget.updateRenderObject.
override
withTooltip(String message, {required Decoration decoration, required bool preferBelow, required EdgeInsetsGeometry padding, required TextStyle textStyle, required Duration waitDuration, required EdgeInsetsGeometry margin}) → Widget

Available on Widget, provided by the WidgetsExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited