SpinKitDancingSquare class

Inheritance
Available extensions

Constructors

SpinKitDancingSquare({Key? key, Color? color, double size = 60.0, IndexedWidgetBuilder? itemBuilder, Duration duration = const Duration(milliseconds: 1200), AnimationController? controller})
const

Properties

color → Color?
final
controller → AnimationController?
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → IndexedWidgetBuilder?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SpinKitDancingSquare>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(GestureTapCallback function) → Widget

Available on Widget, provided by the GestureDetectorExtensions extension

onLongPress(GestureTapCallback function) → Widget

Available on Widget, provided by the GestureDetectorExtensions extension

onTap(GestureTapCallback function) → Widget

Available on Widget, provided by the GestureDetectorExtensions extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withTooltip(String message, {required Decoration decoration, required bool preferBelow, required EdgeInsetsGeometry padding, required TextStyle textStyle, required Duration waitDuration, required EdgeInsetsGeometry margin}) → Widget

Available on Widget, provided by the WidgetsExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited