SpinKitPumpCurve class

Inheritance

Constructors

SpinKitPumpCurve()
const

Properties

flipped → Curve
Returns a new curve that is the reversed inversion of this one.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(double t) → double
Returns the value of the curve at point t.
override
transformInternal(double t) → double
Returns the value of the curve at point t.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

magicNumber → const double