VisibilityDetectorController class

A VisibilityDetectorController is a singleton object that can perform actions and change configuration for all VisibilityDetector widgets.

Properties

debugUpdateCount → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateInterval ↔ Duration
The minimum amount of time to wait between firing batches of visibility callbacks.
getter/setter pair

Methods

forget(Key key) → void
Forgets any pending visibility callbacks for the VisibilityDetector with the given key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyNow() → void
Forces firing all pending visibility callbacks immediately.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → VisibilityDetectorController
no setter