ValidatorUtil class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hasMatch({required String pattern, required String value}) → bool
isFormValid(GlobalKey<FormState>? formKey) → bool
validateEmail(String value, {String? errorMessage}) → String?
validateEmpty(String value, String label) → String?
validateEmptyCheck(String value) → String?
validateName(String value, String label, {String? pattern}) → String?
validatePassword(String value) → String?
validatePattern(String value, {required String label, required String pattern, String? errorMessage}) → String?